


#include <config.h>

#include "ephy-widgets-type-builtins.h"


/* enumerations from "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h" */
#include "/usr/src/ports/epiphany/epiphany-3.8.2-3.x86_64/src/epiphany-3.8.2/lib/widgets/ephy-removable-pixbuf-renderer.h"
GType
ephy_removable_pixbuf_render_policy_get_type (void)
{
  static GType type = 0;

  if (G_UNLIKELY (type == 0))
  {
    static const GEnumValue _ephy_removable_pixbuf_render_policy_values[] = {
      { EPHY_REMOVABLE_PIXBUF_RENDER_PRELIT, "EPHY_REMOVABLE_PIXBUF_RENDER_PRELIT", "prelit" },
      { EPHY_REMOVABLE_PIXBUF_RENDER_NEVER, "EPHY_REMOVABLE_PIXBUF_RENDER_NEVER", "never" },
      { EPHY_REMOVABLE_PIXBUF_RENDER_ALWAYS, "EPHY_REMOVABLE_PIXBUF_RENDER_ALWAYS", "always" },
      { 0, NULL, NULL }
    };

    type = g_enum_register_static ("EphyRemovablePixbufRenderPolicy", _ephy_removable_pixbuf_render_policy_values);
  }

  return type;
}




